#
# spec file for package dynamips
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dynamips
Version:        0.2.23
Release:        3.2
Summary:        Cisco router Emulator
License:        GPL-2.0-or-later
Group:          System/Emulators/Other
URL:            https://www.gns3.net
Source:         https://github.com/GNS3/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         define-s390x-arch.patch
BuildRequires:  cmake
BuildRequires:  libelf-devel
BuildRequires:  libpcap-devel
%ifarch x86_64
%if %{undefined fedora}
BuildRequires:  glibc-32bit
BuildRequires:  glibc-devel-32bit
%endif
%endif

%description
Cisco Router Emulator supported by GNS3 Community

Dynamips emulates Cisco 7200/3600/3725/3745/2691 Routers on a traditional PC.
You can use dynamips to create labs. It uses IOS Images (which are not part
of this package). Of course, this emulator cannot replace a real router. It is
simply a complementary tool to real labs for administrators of Cisco networks
or people wanting to pass their CCNA/CCNP/CCIE exams.

%prep
%autosetup -p1

%build
%cmake \
%ifarch x86_64
  -DYNAMIPS_ARCH=amd64 \
%endif
  -DCMAKE_INSTALL_DOCDIR:STRING=%{_datadir}/doc/%{name} \
%{nil}

%cmake_build

%install
%cmake_install

%check

%files
%{_bindir}/%{name}
%{_bindir}/nvram_export
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/nvram_export.1%{?ext_man}
%{_mandir}/man7/hypervisor_mode.7%{?ext_man}
%{_datadir}/doc/%{name}

%changelog
* Mon Apr  8 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add empty %%check section.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Set CMAKE_INSTALL_DOCDIR to work around incompatible changes
  added to macros.cmake.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Thu Jan 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.23
  * Add Command line option to configure console binding for
    TCP/AUX console.
* Sun Jan  8 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.23:
  * Command line option to configure console binding for TCP/AUX console.
  - Fallbacks to the hypervisor binding address if not set.
* Tue May 24 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.22
  * Fix stack alignment for JIT function call targets.
* Wed Dec 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.21
  * Fix SEGV during snprintf and localtime_r.
- Update to version 0.2.20
  * New fix for segmentation fault when using localtime()
- Update to version 0.2.19
  * Fix segmentation fault when using localtime() (64-bit only).
- Update to version 0.2.18
  * Allow to reuse socket in udp_connect.
  * Fix segfault when exporting startup-config.
* Sun Feb 18 2018 avindra@opensuse.org
- new upstream version 0.2.17
  * Set nonblocking I/O for UDP sockets
  * NM-16ESW: process packets even if MAC address table is full
- remove dos2unix, no longer needed
- use cmake macros to build
* Tue Feb 28 2017 mpost@suse.com
- Added define-s390x-arch.patch to enable building on s390x.
* Fri Mar 25 2016 andrea@opensuse.org
- new upstream version 0.2.16
  * Remove libuuid dependency and NIO Multicast implementation that depends on it.
    NIO Multicast is never used and maybe not even functional.
  * EthernetSwitch: Allow to choose ethertype for QinQ outer tag
* Thu Jun  4 2015 andrea@opensuse.org
- New upstream version 0.2.15
  * minor fixes for OSX
- removed dynamips-0.2.14_fix_hanging_ethsw_add_nio.patch
* Sun Nov 30 2014 andrea@opensuse.org
- added dynamips-0.2.14_fix_hanging_ethsw_add_nio.patch
  to fix upstream bug 59 https://github.com/GNS3/dynamips/issues/59
* Thu Sep 25 2014 andrea@opensuse.org
- new upstream version 0.2.14
  * Add optional argument 'format' to hypervisor commands 'send_con_msg' and
    'send_aux_msg'. Report "X byte(s) written" on succeess.
  * String formats:
  - plain - plain string (default, old behavior)
  - base64 - base64 encoded string
  * Fix issue with 7200 IOS crashing after restart
  * Fixed issue #49 - IOS crashes after router restart
  * Fixed issue #50 - vm send_con_msg
* Fri Jul 11 2014 andrea@opensuse.org
- new upstream version 0.2.13
  - MPC860: Add debug message for the unimplemented CP reset command
  - Report the partid of dev_am79c971 type AM79C971_TYPE_10BASE_T as Am79C970A.
  - Fixes the "AMD Unknown" that shows up in "show controllers".
    IOS calls this "AMD Presidio" or "AmdP2".
  - MPC860 FEC: (logic is inlined in dev_mpc860.c for now)
  - implement PHY LXT970A, which was hardcoded as values in the MII registers
  - if sending with link down, report no heartbeat and lost carrier
  - PCMCIA disk:
  - annotate the "Card Information Structure" data
  - add missing CISTPL_END
  - Document Cisco EEPROM format v1 and v4.
  - Add CMake build system.
  - Missing empty line at end of fs_nvram.c
  - Fix unused function warnings.
  - Remove unused duplicate of physmem_get_hptr from stable/mips64_jit.c
  - Add test builds using Travis CI.
  - Create new README.md based on README for GitHub frontpage.
  - Add common.h.
  - Move generic includes, types and macros from utils.h to common.h.
  - Minimize includes in sbox.c/h.
  - Minimize includes in crc.c/h.
  - Fix unstable nojit compilation.
  - Fix unused variable warning in ppc32_jit.c.
  - Use dev_dec21140.c from unstable.
  - Fix bandwidth statistics
  - Check if the NIO can trasmit
  - Add #pragma once to common.h
  - Rename common.h to dynamips_common.h.
  - Delete ds1620.h.
  - This file is not used and most of the constants are in dev_ds1620.c.
  - Tell the compiler that mem_bswap32 does not require aligned data.
  - Minimize headers.
  - define FD_SETSIZE for Cygwin in dynamips_common.h
  - Rename double underscore macros:
  - rename __not_aligned to _not_aligned
  - rename __maybe_unused to _maybe_used
  - rename __unused to _unused
  - Use an exclusive lock while dumping captured packets. (thread safety)
  - Respect the snapshot length of the descriptor.
  - Report failed setups of hypervisor command 'nio setup_filter'.
  - Make a single FAT16 partition when pcmia disks are first created.
  - Change pcap snapshot length to 65535.
  - Remove old Makefiles to avoid confusion. (not gonna be maintained)
  - Improve TX performance of i8254x (PA-GE) by sending up to 16 packets at a time.
  - Merge pull request #45 from candlerb/candlerb/txperformance
  - Print the device name when debugging pci accesses.
  - Indicate the TODO list is from the original author.
  - Fix for issue #9 - Reproducable crash
  - Fixed issue #38 - Unknown file system detected
  - Fixed issue #41 - "Frame is Too Long" error in Wireshark
* Sun May 11 2014 andrea@opensuse.org
- Removed some fedora code from spec file, moved to project conf
* Tue Apr  1 2014 andrea@opensuse.org
- new upstream version 0.2.12
  * Fixed all known multicast issues. Patches by Peter Palúch.
  * New hypervisor command:
  - vm_debug pmem_cfind <instance_name> <cpu_id> <bytes> [<first> [<last>]]
  * Fixed issue #29
  * Closed issue #31
- removed multicast patches now merged in upstream code
* Mon Mar  3 2014 andrea@opensuse.org
- Fixed multicast related bugs adding the following two patches:
  * dynamips-0.2.11_fix_M_bit.patch
  * dynamips-0.2.11_fix_mcast_queue.patch
* Wed Feb 19 2014 junghans@votca.org
- clean up spec file
* Mon Feb 17 2014 andrea@opensuse.org
- new upstream version 0.2.11
  * Full update of hypervisor documentation.
  * Change default NPE for c7200 platform from npe-200 to npe-400.
  * New hypervisor commands
  * Fixed issue #20 - segmentation fault when accessing a device
    that failed to memory map it's file
  * Implemented enhancement #21 - Renaming devices
  * Closed issue #22 - Hypervisor documentation is out of date
  * Implemented enhancement #36 - hypervisor command to clean
    the files of a vm
  * Fixed issue #27 - Rename issues.
  * Old text is replayed when you connect to the console/aux port.
  * Warn the VM isn't running when connecting to the console/aux port.
* Sat Nov 16 2013 andrea@opensuse.org
- Minor spec file clean up
- Added dos2unix to convert documentation files
* Sat Nov  9 2013 andrea@opensuse.org
- Bump to stable 0.2.10
* Fri Jul 12 2013 obs@noles.co.uk
- Bump to stable 0.2.8
- Switch to maintained fork of dynamips
* Thu Jul 26 2012 dmueller@suse.com
- fix build on ARM
* Thu Mar 22 2012 dvaleev@suse.com
- fix ppc and ppc64 builds
* Sat May 28 2011 cfarrell@novell.com
- license update: GPL-2.0+
  Always state version of license in spec file. Use syntax from
  spdx.org/licenses
* Mon Apr 11 2011 andrea@opensuse.org
- update to version 0.2.8 RC3 from gns3 community project
* Fri Jun 20 2008 crrodriguez@suse.de
- update to version 0.2.8 RC2 per user requests
